* {
    margin: 0;
    padding: 0;
}

html, body {
    height: 100%;
}

body {
    background-color: white;
    color: black;
    font-size: 12pt;
    font-family: "Cantarell", sans-serif;
    width: 100%;
}

a, a:visited, a:active, a:link {
    color: #3C6EB4;
    text-decoration: none;
}

legend {
    font-size: 1.2em;
    padding-bottom: 10px;
}

/* Header Styles */
.header {
    color: #3158AF;
    height: 75px;
}
.header a {
    text-decoration: none;
}

#site-logo {
    width: 142px;
    height: 75px;
    background-image: url(../img/fedora_badges_small.png);
    background-repeat: no-repeat;
    margin-right: 10px;
    margin-left: 10px;
    margin-top: 10px;
    background-size: contain;
    background-position-y: center;
}

/* Applied to numbering, mainly (ex. #1, #2, etc.). */
.big-text {
    font-size: 2em;
}

.pretty-list {
    list-style: none;
    margin-left: 10px;
}

.pretty-list li {
    vertical-align: middle;
    background: url(../img/badge_bullet_fedora.png) no-repeat left center;
    padding-left: 50px;
    padding-top: 15px;
    padding-bottom: 15px;
}

.page {
    min-height: calc(100% - 1em);
}

.page-content {
    overflow: auto;
    padding-bottom: 7em;
}

/* Footer Styles */

footer {
    position: relative;
    margin-top: -9em;
    height: 9em;
    clear: both;
    color: #9B9B9B;
    font-size: 10px;
    text-align: center;
}

.date {
    font-size: 0.8em;
    color: #9B9B9B; /* Dark gray */
    display: block;
}

.navbar {
    list-style-type: none;
    background: #3158AF;
    color: white;
    width: 100%;
    padding: 5px 0;
    margin-left: -8px; /* There has to be a better way. */
    margin-top: 20px;
}

.navbar li {
    display: inline;
    padding: 10px;
}

.navbar a {
    color: white;
    text-decoration: none;
}

table {
    border-spacing: 0;
    width: 100%;
}

td {
    padding: 10px;
}

tr:nth-child(odd) { background: #E8EFF8; } /* "Clear day" */

tr:nth-child(even) { background: white; }

.admin-form td {
    min-width: 300px;
}

.admin-form tr {
    background: white;
}

#logo {
    color: #9B9B9B; /* Dark gray */
}

#sublogo {
    vertical-align: 35%;
    padding-left: 15px;
    font-size: 50%;
}

/* This is applied to the content of columns, but not to the header,
 * so that the content is a bit less-wide than the header.
 * (on suggestion of Jenn Kotler)
 */
.padded-content {
    padding-left: 10px;
    padding-right: 10px;
    padding-bottom: 15px;
}


.downshift {
    margin-top: 0px !important;
    margin-bottom: 0px !important;
}

.downshift-20 {
    margin-top: 20px !important;
    margin-bottom: 0px !important;
}

/* Applied to <button> tags. */
.pretty-button {
    background: #3158AF;
    color: white;
    text-align: center;
    padding: 10px;
    margin-top: 10px;
    margin-bottom: 10px;
    height: 50px;
    width: 100%;
}

/* Applied to actual submit buttons (on forms). */
.pretty-submit {
    background: #3158AF;
    color: white;
    text-align: center;
    height: 50px;
    width: 100%;
}

.section-header {
    background: #3158AF;
    color: white;
    text-align: center;
    padding: 10px;
    margin-top: 10px;
    margin-bottom: 10px;
}

.collapsed-row {
    visibility: collapse;
}

.name {
    font-size: 1.4em;
    font-weight: bold;
    margin-top: 5px;
    margin-bottom: 5px;
}

.description {
    font-size: 1.2em;
    margin: 20px;
}

.metadata {
    font-size: 0.8em;
    color: #666;
    margin: 0px;
    margin-bottom:   15px;
}

.badge-image {
    width: 15%;
    text-align: center;
}

.badge-assertions {
    width: 35%;
}

.badge-assertions ul {
    list-style-type: none;
    margin: 0px;
    padding: 0px;
}

.badge-assertions li {
    padding-left: 15px;
}

.weak {
    color: #666;
    font-style: italic;
}

.sublabel {
    display: block;
    font-size: 0.8em;
    color: #666;
}

.thumbnail-responsive {
    width: 100%;
    height: 100%;
}

.thumbnail-responsive img {
    max-width: 100%;
    width: auto/9;
    height: auto;
    vertical-align: middle;
    border: 0;
    -ms-interpolation-mode: bicubic;
}

.thumbnail-256, .thumbnail-256 img {
    width: 256px;
    height: 256px;
}

.thumbnail-96, .thumbnail-96 img {
    width: 96px;
    height: 96px;
}

.thumbnail-64, .thumbnail-64 img {
    width: 64px;
    height: 64px;
}

.thumbnail img {
    display: block;
    margin-left: auto;
    margin-right: auto;
}

.thumbnail {
    margin-left: auto;
    margin-right: auto;
}

.thumbnail-container {
    margin-top: 5px;
    margin-bottom: 5px;
}

.text-64 {
    text-align: center;
    margin-top: 18px;
}

.tooltip {
    /* Nothing, Lebowski. */
}

.shadow {
    box-shadow: 1px 1px 10px rgba(0, 0, 0, 0.5);
}

.tooltip::after {
    background: rgba(0, 0, 0, 0.8);
    border-radius: 8px 8px 8px 0px;
    box-shadow: 1px 1px 10px rgba(0, 0, 0, 0.5);
    color: #FFF;
    content: attr(data-tooltip); /* amazing */
    opacity: 0; /* Our element is transparent... */
    padding: 3px 7px;
    position: absolute;
    visibility: hidden; /* ...and hidden. */
    transition: all 0.4s ease-in-out; /* To add some smoothness */
}

.tooltip-bottom::after {
    border-radius: 8px 0px 8px 8px;
}

.tooltip:hover::after {
    opacity: 1; /* Make it visible */
    visibility: visible;
}

.tooltip-64:after {
    margin-top: -96px;
    margin-left: 64px;
}

.tooltip-128:after {
    margin-top: -28px;
}

.tooltip-256:after {
    margin-top: -28px;
}

img.badge-64 {
    width: 64px;
    height: 64px;
}

img.badge-128 {
    width: 128px;
    height: 128px;
}

img.badge-256 {
    width: 256px;
    height: 256px;
}

/* Clearfix */
.clearfix:after {
    content: ".";
    display: block;
    height: 0;
    clear: both;
    visibility: hidden;
}

.document {
    padding: 20px;
}

/* This is so that the version number line, external to the sitedocs/footer.rst
 * file, is not pushed away from the rest of the footer content.
 */
footer > .document {
    padding: 0px;
}

/* Center the badges fan on the about page */
.document img {
    display: block;
    margin-left: auto;
    margin-right: auto;
}

.document p {
    margin: 12px;
}

.document h1 {
    border-bottom: 1px solid #cccccc;
}

.document h1, .document h2 {
    margin: 10px 0;
}

.document h2 {
    font-size: 130%;
}

.document li {
    margin-left: 30px;
}

.centered {
    margin-left: auto;
    margin-right: auto;
    text-align: center;
}

.name > small {
    color: #888888;
}

@media all and (max-width:  768px) {
    .mobile-hidden {
        display: none !important;
    }
}

.flex-container {
    display: flex;
    flex-direction: row;
    flex-wrap: wrap;
}

#header-search {
    margin-top: 35px;
    float: right;
}

.header > h1 {
    display: inline-block;
}
