function activate_social_links() {
    // Set up the twitter link
    (function(d,s,id){
        var js,fjs=d.getElementsByTagName(s)[0],p=/^http:/.test(d.location)?'http':'https';
        if(!d.getElementById(id)){js=d.createElement(s);
            js.id=id;
            js.src=p+'://platform.twitter.com/widgets.js';
            fjs.parentNode.insertBefore(js,fjs);
        }
    })(document, 'script', 'twitter-wjs');

    $("#social-activate").slideUp('slow');
    setTimeout(function() {
        $("#twitter-container").show();
    }, 500);
}

$(document).ready(function() {
    $("#twitter-container").hide();
})
